@@ -10,6 +10,8 @@ from pyubee import Ubee
 logging.basicConfig()
 _LOGGER = logging.getLogger('pyubee')
 _LOGGER.setLevel(logging.ERROR)
+_LOGGER_TRAFFIC = logging.getLogger('pyubee.traffic')
+_LOGGER_TRAFFIC.setLevel(logging.ERROR)
 
 
 def main():
@@ -22,11 +24,16 @@ def main():
                         help='Model, supported models: ' + ', '.join(SUPPORTED_MODELS))
     parser.add_argument('-d', '--debug', action='store_true',
                         help='Enable debug-logging')
+    parser.add_argument('-t', '--show-traffic', action='store_true',
+                        help='Show sent/received traffic')
     args = parser.parse_args()
 
     if args.debug:
         _LOGGER.setLevel(logging.DEBUG)
 
+    if args.show_traffic:
+        _LOGGER_TRAFFIC.setLevel(logging.DEBUG)
+
     ubee = Ubee(host=args.host,
                 username=args.username,
                 password=args.password,
